def caesar_encrypt(text, shift):
    # 凯撒加密 （重新写的）
    ciphertext = ''
    for p in text:
        if 'a' <= p <= 'z':
            ciphertext += chr(ord('a') + (ord(p) - ord('a') + shift) % 26)
        elif 'A' <= p <= 'Z':
            ciphertext += chr(ord('A') + (ord(p) - ord('Z') + shift) % 26)
        else:
            ciphertext += p
    return ciphertext


def caesar_decrypt(text, shift):
    # 凯撒解密 （一样，重新写的）
    ciphertext = ''
    for p in text:
        if 'a' <= p <= 'z':
            ciphertext += chr(ord('a') + (ord(p) - ord('a') - shift) % 26)
        elif 'A' <= p <= 'Z':
            ciphertext += chr(ord('A') + (ord(p) - ord('Z') - shift) % 26)
        else:
            ciphertext += p
    return ciphertext


def caesar_decrypt_cracking(ciphertext):
    # 凯撒解密爆破，返回值为列表
    results = []
    for i in range(1, 26):
        plaintext = caesar_decrypt(ciphertext,i)
        results.append("您的偏移量为{}，结果为{}".format(i, plaintext))
    return results

def caesar_encrypt_cracking(ciphertext):
    # 凯撒解密爆破，返回值为列表
    results = []
    for i in range(1, 26):
        plaintext = caesar_encrypt(ciphertext,i)
        results.append("您的偏移量为{}，结果为{}".format(i, plaintext))
    return results



# 其他CTF能力
# 2023年1月1日
# 末心
import os
import execjs  # PyExecJS
from qsnctf.auxiliary import js_from_file
# 社会主义核心价值观编码
# 需要将Python目录下>lib>subprocess.py的765行附近的encoding的默认None值修改为utf-8即可。


def Chinese_socialism_encode(data):
    # 社会主义核心价值观编码
    package_path = os.path.abspath(os.path.dirname(__file__))
    file_path = os.path.join(package_path, 'plugin', 'js', 'cvencode.js')
    content = execjs.compile(js_from_file(file_path))
    result = content.call('encode', data)
    result = str(result)
    return result


def Chinese_socialism_decode(data):
    # 社会主义核心价值观解码
    package_path = os.path.abspath(os.path.dirname(__file__))
    file_path = os.path.join(package_path, 'plugin', 'js', 'cvencode.js')
    content = execjs.compile(js_from_file(file_path))
    result = content.call('decode', data)
    result = str(result)
    return result


def string_reverse(string):
    # 字符串逆向
    return string[::-1]


# Base编码解码功能
# 2023年1月1日
# 末心
import base64


def base64_encode(text):
    code = (base64.b64encode(text.encode('utf-8'))).decode('utf-8')
    return code


def base64_decode(text):
    code = (base64.b64decode(text.encode('utf-8')))
    return code.decode('utf-8')


def base32_encode(text):
    code = (base64.b32encode(text.encode('utf-8'))).decode('utf-8')
    return code


def base32_decode(text):
    code = (base64.b32decode(text.encode('utf-8')))
    return code.decode('utf-8')


def base16_encode(text):
    code = (base64.b16encode(text.encode('utf-8'))).decode('utf-8')
    return code


def base16_decode(text):
    code = (base64.b16decode(text.encode('utf-8')))
    return code.decode('utf-8')


def base85_encode(text):
    code = (base64.b85encode(text.encode('utf-8'))).decode('utf-8')
    return code


def base85_decode(text):
    code = (base64.b85decode(text.encode('utf-8')))
    return code.decode('utf-8')
